# AgIcons

A Python icons module.
## Installation

```bash
pip install AgIcons
```

## Usage

```python
from AgIcons import *

icon = Icon('camera', 'outline')
if icon:
    print(f"Icon found: {icon}")
else:
    print("Icon not found.")
```
